@@ -3,7 +3,10 @@ package Search::Xapian;
 use 5.006;
 use strict;
 use warnings;
-use Carp;
+
+our $VERSION = '1.0.5.0';
+
+use Exporter 'import';
 
 use Search::Xapian::Database;
 use Search::Xapian::Document;
@@ -11,11 +14,13 @@ use Search::Xapian::ESet;
 use Search::Xapian::ESetIterator;
 use Search::Xapian::MSet;
 use Search::Xapian::MSetIterator;
+use Search::Xapian::MultiValueSorter;
 use Search::Xapian::PositionIterator;
 use Search::Xapian::PostingIterator;
 use Search::Xapian::Query;
 use Search::Xapian::QueryParser;
 use Search::Xapian::RSet;
+use Search::Xapian::Stem;
 use Search::Xapian::TermGenerator;
 use Search::Xapian::TermIterator;
 use Search::Xapian::ValueIterator;
@@ -28,10 +33,9 @@ use Search::Xapian::TradWeight;
 use Search::Xapian::SimpleStopper;
 use Search::Xapian::PerlStopper;
 
-require Exporter;
 require DynaLoader;
 
-our @ISA = qw(Exporter DynaLoader);
+our @ISA = qw(DynaLoader);
 
 # Items to export into callers namespace by default. Note: do not export
 # names by default without a very good reason. Use EXPORT_OK instead.
@@ -72,6 +76,10 @@ our %EXPORT_TAGS = (
 				 FLAG_WILDCARD
 				 FLAG_PURE_NOT
 				 FLAG_PARTIAL
+				 FLAG_SPELLING_CORRECTION
+				 FLAG_SYNONYM
+				 FLAG_AUTO_SYNONYMS
+				 FLAG_AUTO_MULTIWORD_SYNONYMS
                                  ) ],
                     'qpstem' => [ qw(
 				 STEM_NONE
@@ -90,9 +98,6 @@ our @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } );
 
 our @EXPORT = qw( );
 
-
-our $VERSION = '1.0.3.0';
-
 bootstrap Search::Xapian $VERSION;
 
 # Preloaded methods go here.
@@ -155,9 +160,15 @@ can read the Xapian C++ API documentation at
 L<http://www.xapian.org/docs/apidoc/html/annotated.html> for details of
 these.  Alternatively, take a look at the code in the examples and tests.
 
-If you encounter problems, email either me or preferably the
-Xapian-discuss mailing list (which I am on - subscription details can
-be found on the Xapian web site L<http://www.xapian.org/lists.php>).
+If you want to use Search::Xapian and the threads module together, make
+sure you're using Search::Xapian >= 1.0.4.0 and Perl >= 5.8.7.  As of 1.0.4.0,
+Search::Xapian uses CLONE_SKIP to make sure that the perl wrapper objects
+aren't copied to new threads - without this the underlying C++ objects can get
+destroyed more than once.
+
+If you encounter problems, or have any comments, suggestions, patches, etc
+please email the Xapian-discuss mailing list (details of which can be found at
+L<http://www.xapian.org/lists.php>).
 
 =head2 EXPORT
 
@@ -368,8 +379,28 @@ advice, bugfixes, and wrapper code for the more obscure classes.
 
 Alex Bowley E<lt>kilinrax@cpan.orgE<gt>
 
+Please report any bugs/suggestions to E<lt>xapian-discuss@lists.xapian.orgE<gt>
+or use the Xapian bug tracker L<http://www.xapian.org/bugs/>.  Please do
+NOT use the CPAN bug tracker or mail any of the authors individually.
+
 =head1 SEE ALSO
 
-L<perl>. L<xapian>.
+L<Search::Xapian::BM25Weight>,
+L<Search::Xapian::BoolWeight>,
+L<Search::Xapian::Database>,
+L<Search::Xapian::Document>,
+L<Search::Xapian::Enquire>,
+L<Search::Xapian::PositionIterator>,
+L<Search::Xapian::PostingIterator>,
+L<Search::Xapian::QueryParser>,
+L<Search::Xapian::Stem>,
+L<Search::Xapian::TermGenerator>,
+L<Search::Xapian::TermIterator>,
+L<Search::Xapian::TradWeight>,
+L<Search::Xapian::ValueIterator>,
+L<Search::Xapian::Weight>,
+L<Search::Xapian::WritableDatabase>,
+and
+L<http://www.xapian.org/>.
 
 =cut
